require "didww_ups/version"
require "logger"
require "activeresource-response"
require 'active_support/core_ext/module'

module DidwwUps

  SANDBOX_HOST = 'dev-payments.didww.com'

  PRODUCTION_HOST = 'ups.didww.com'

  mattr_accessor :service_host
  mattr_accessor :config
  mattr_accessor :logger
  mattr_accessor :global_store
  self.logger = ::Logger.new($stdout)

   def self.configure(env)
     @configuration_env = env
     all_configs = load_configuration


     if all_configs.any?
       self.config = all_configs[env].symbolize_keys
       if config[:ups_host].present?
         self.service_host = config[:ups_host]
       else
         self.environment = config[:ups_env]
       end
       DidwwUps::Base.site = 'https://' + self.service_host
       store = DidwwUps::Store.new(api_public_key: config[:store_public_key], api_secret_key: config[:store_secret_key])
       DidwwUps.global_store = store
       DidwwUps.store = store
     end
   end


  def self.environment=(env)
    env = env.to_sym
    if [:live, :production].include? env
      self.service_host = PRODUCTION_HOST
    elsif [:test, :development, :sandbox].include? env
      self.service_host = SANDBOX_HOST
    else
      raise ArgumentError.new("environment= #{env} accepts any of :live, :production, :test, :sandbox")
    end
  end

  def self.current_store
    Thread.current['didww_ups.active_store'] || DidwwUps.global_store
  end

  def self.profile
    current_store.class.profile
  end

  #
  def self.store=(store)
    Thread.current['didww_ups.active_store'] = store
  end

  def self.with_configuration(new_env)
    old_env = @configuration_env
    begin
      self.configure(new_env)
      yield if block_given?
    ensure
      self.configure(old_env)
    end
  end

  def self.with_store(new_store)
    old_store = current_store
    begin
      self.store = new_store
      yield if block_given?
    ensure
      self.store=old_store
    end
  end

  def self.load_configuration
    config_file = ENV['DIDWW_UPS_CONFIG_FILE'] || 'config/didww_ups.yml'
    if File.exist?(config_file)
      YAML.load_file(config_file)
    else
      raise StandardError.new("File #{config_file} doesn't exist") if   ENV['DIDWW_UPS_CONFIG_FILE'].present?
      logger.warn "Can't find #{config_file}"
      {}
    end
  end


end


require "didww_ups/connection"
require "didww_ups/collection"
require "didww_ups/base"
require "didww_ups/store"
require "didww_ups/credit_card"
require "didww_ups/payment"
require "didww_ups/refund"
require "didww_ups/modules_base"
require "didww_ups/modules_token"
require "didww_ups/modules_payment"
require "didww_ups/modules_refund"
require 'yaml'
if defined? Rails
  require 'didww_ups/railtie'
  require 'generators/config'
else
  DidwwUps.configure(ENV['RACK_ENV'])
end




