# DidwwUps::Refund class to handle Refunds
#
# Routes:
#   GET        /api/rest/v1/refunds(.:format)
#   POST       /api/rest/v1/refunds(.:format)
#
# Filter Examples
#   refunds = DidwwUps::Refund.all(params: { page:1, per_page:10 , q:{success_eq: true}})
#   # => GET "/api/rest/v1/refunds?page=1&per_page=10&q%5Bsuccess_eq%5D=true"
#
# Methods for pagination
#   # refunds.total_count
#   # refunds.limit_value
#   # refunds.offset_value
#
#
# Possible filter keys for params[:q]
#    * +:created_at_gte+
#    * +:created_at_lte+
#    * +:store_id_eq+
#    * +:amount_eq+
#    * +:description_contains+
#    * +:operator_contains+
#    * +:order_id_eq+
#    * +:success_eq+
#
# Create Refund
#
# Example failed by merchant
#   refund = DidwwUps::Refund.create(order_id: "1294526", amount:12.00, operator: "Bob", description: "Stolen Card")
#   # => "{\"id\":466,\"success\":false,\"Credit Card is expired\":null,\"amount\":12.0,\"order_id\":\"1294526\",\"description\":\"Stolen Card\",\"operator\":\"Bob\"}"
#   refund.valid?   # => true
#   refund.success? # => false
#
# Example failed by UPS
#   refund = DidwwUps::Refund.create(order_id: "1294526", amount:1000.00, operator: "Bob", description: "Stolen Card")
#   # => "{\"errors\":{\"amount\":[\"must be less or equal to 14.0\"]}}"
#   refund.success? # => false
#   refund.valid?   #  => false
#   errors.full_messages  #  => ["Amount must be less or equal to 14.0"]
#
# Example successfull
#   refund = DidwwUps::Refund.create(order_id: "1294526", amount:12.00, operator: "Bob", description: "Stolen Card")
#   # => "{\"id\":466,\"success\":true,\"error\":null,\"amount\":12.0,\"order_id\":\"1294526\",\"description\":\"Stolen Card\",\"operator\":\"Bob\"}"
#   refund.success?  # => true
#   refund.valid?    # =>  true
#
# Params
# * +:amount+ - amount of refund,  if not present payment amount is used
# * +:description+ - Description of refund,  if not present payment description is used
# * +:operator+ - responsible for refund,  if not present payment operator is used
# * +:order_id+ - order_id  of payment
#
module DidwwUps
  class Refund < DidwwUps::Base

    def created_at
      Time.parse(self[:created_at])
    end

    def success?
      valid? && persisted? && success
    end
  end
end